==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/MessageBar/MessageBar.base.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Watch, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import '../node_modules/core-js/modules/es.number.constructor.js';
import { Icon } from '../Icon/index.js';
import '../Button/BaseButton.js';
import '../Button/ActionButton/ActionButton.js';
import '../Button/DefaultButton/DefaultButton.js';
import '../Button/PrimaryButton/PrimaryButton.js';
import '../Button/CommandBarButton/CommandBarButton.js';
import '../Button/CompoundButton/CompoundButton.js';
import { IconButton } from '../Button/IconButton/IconButton.js';
import '../Button/MessageBarButton/MessageBarButton.js';
import { MessageBarType } from './MessageBar.types.js';

var _ICON_MAP;

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();
var ICON_MAP = (_ICON_MAP = {}, _defineProperty(_ICON_MAP, MessageBarType.info, 'Info'), _defineProperty(_ICON_MAP, MessageBarType.warning, 'Info'), _defineProperty(_ICON_MAP, MessageBarType.error, 'ErrorBadge'), _defineProperty(_ICON_MAP, MessageBarType.blocked, 'Blocked2'), _defineProperty(_ICON_MAP, MessageBarType.severeWarning, 'Warning'), _defineProperty(_ICON_MAP, MessageBarType.success, 'Completed'), _ICON_MAP);

var MessageBarBase = function (_BaseComponent) {
  _inherits(MessageBarBase, _BaseComponent);

  var _super = _createSuper(MessageBarBase);

  function MessageBarBase() {
    var _this;

    _classCallCheck(this, MessageBarBase);

    _this = _super.apply(this, arguments);
    _this.state = {
      expandSingleLine: _this.expandSingleLine
    };
    return _this;
  }

  _createClass(MessageBarBase, [{
    key: "onExpandSingleLine",
    value: function onExpandSingleLine(value) {
      this.state.expandSingleLine = value;
    }
  }, {
    key: "onClick",
    value: function onClick() {
      this.state.expandSingleLine = !this.state.expandSingleLine;
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      var theme = this.theme,
          classNames = this.classNames,
          messageBarType = this.messageBarType,
          actions = this.actions,
          truncated = this.truncated,
          isMultiline = this.isMultiline;
      return h("div", {
        "style": {
          background: theme.semanticColors.bodyBackground
        }
      }, [h("div", {
        "class": classNames.root
      }, [h("div", {
        "class": classNames.content
      }, [h("div", {
        "class": classNames.iconContainer
      }, [h(Icon, {
        "class": classNames.icon,
        "attrs": {
          "icon-name": ICON_MAP[messageBarType]
        }
      })]), h("div", {
        "class": classNames.text,
        "attrs": {
          "role": "status"
        }
      }, [h("span", {
        "class": classNames.innerText
      }, [h("span", [this.$slots["default"]])])]), !actions && truncated && h("div", {
        "class": classNames.expandSingleLine
      }, [h(IconButton, {
        "class": classNames.expand,
        "attrs": {
          "icon-props": {
            iconName: this.state.expandSingleLine ? 'DoubleChevronUp' : 'DoubleChevronDown'
          }
        },
        "nativeOn": {
          "click": this.onClick
        }
      })]), !isMultiline && this.$slots.actions && h("div", {
        "class": classNames.actions
      }, [this.$slots.actions]), this.$listeners.dismiss && isMultiline && h(IconButton, {
        "class": classNames.dismissal,
        "attrs": {
          "icon-props": {
            iconName: 'Clear'
          }
        }
      }), this.$listeners.dismiss && !isMultiline && h("div", {
        "class": classNames.dismissSingleLine
      }, [h(IconButton, {
        "class": classNames.dismissal,
        "attrs": {
          "icon-props": {
            iconName: 'Clear'
          }
        }
      })])]), isMultiline && this.$slots.actions && h("div", {
        "class": classNames.actions
      }, [this.$slots.actions])])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          className = this.className,
          messageBarType = this.messageBarType,
          actions = this.actions,
          truncated = this.truncated,
          isMultiline = this.isMultiline;
      var expandSingleLine = this.state.expandSingleLine;
      return getClassNames(this.styles, {
        theme: theme,
        messageBarType: messageBarType || MessageBarType.info,
        onDismiss: this.$listeners.dismiss !== undefined,
        actions: actions !== undefined,
        truncated: truncated,
        isMultiline: isMultiline,
        expandSingleLine: expandSingleLine,
        className: className
      });
    }
  }]);

  return MessageBarBase;
}(BaseComponent);

__decorate([Prop({
  type: Number,
  "default": MessageBarType.info
}), __metadata("design:type", Number)], MessageBarBase.prototype, "messageBarType", void 0);

__decorate([Prop({
  type: Boolean,
  "default": true
}), __metadata("design:type", Boolean)], MessageBarBase.prototype, "isMultiline", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], MessageBarBase.prototype, "actions", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], MessageBarBase.prototype, "truncated", void 0);

__decorate([Prop({
  type: Boolean,
  "default": true
}), __metadata("design:type", Boolean)], MessageBarBase.prototype, "expandSingleLine", void 0);

__decorate([Watch('expandSingleLine'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean]), __metadata("design:returntype", void 0)], MessageBarBase.prototype, "onExpandSingleLine", null);

MessageBarBase = __decorate([Component({
  components: {
    Icon: Icon,
    IconButton: IconButton
  }
})], MessageBarBase);

export { MessageBarBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/MessageBar/MessageBar.base.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Watch, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import 'core-js/modules/es.number.constructor';
import { Icon } from '../Icon/index.js';
import '../Button/BaseButton.js';
import '../Button/ActionButton/ActionButton.js';
import '../Button/DefaultButton/DefaultButton.js';
import '../Button/PrimaryButton/PrimaryButton.js';
import '../Button/CommandBarButton/CommandBarButton.js';
import '../Button/CompoundButton/CompoundButton.js';
import { IconButton } from '../Button/IconButton/IconButton.js';
import '../Button/MessageBarButton/MessageBarButton.js';
import { MessageBarType } from './MessageBar.types.js';

var _ICON_MAP;

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();
var ICON_MAP = (_ICON_MAP = {}, _defineProperty(_ICON_MAP, MessageBarType.info, 'Info'), _defineProperty(_ICON_MAP, MessageBarType.warning, 'Info'), _defineProperty(_ICON_MAP, MessageBarType.error, 'ErrorBadge'), _defineProperty(_ICON_MAP, MessageBarType.blocked, 'Blocked2'), _defineProperty(_ICON_MAP, MessageBarType.severeWarning, 'Warning'), _defineProperty(_ICON_MAP, MessageBarType.success, 'Completed'), _ICON_MAP);

var MessageBarBase = function (_BaseComponent) {
  _inherits(MessageBarBase, _BaseComponent);

  var _super = _createSuper(MessageBarBase);

  function MessageBarBase() {
    var _this;

    _classCallCheck(this, MessageBarBase);

    _this = _super.apply(this, arguments);
    _this.state = {
      expandSingleLine: _this.expandSingleLine
    };
    return _this;
  }

  _createClass(MessageBarBase, [{
    key: "onExpandSingleLine",
    value: function onExpandSingleLine(value) {
      this.state.expandSingleLine = value;
    }
  }, {
    key: "onClick",
    value: function onClick() {
      this.state.expandSingleLine = !this.state.expandSingleLine;
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      var theme = this.theme,
          classNames = this.classNames,
          messageBarType = this.messageBarType,
          actions = this.actions,
          truncated = this.truncated,
          isMultiline = this.isMultiline;
      return h("div", {
        "style": {
          background: theme.semanticColors.bodyBackground
        }
      }, [h("div", {
        "class": classNames.root
      }, [h("div", {
        "class": classNames.content
      }, [h("div", {
        "class": classNames.iconContainer
      }, [h(Icon, {
        "class": classNames.icon,
        "attrs": {
          "icon-name": ICON_MAP[messageBarType]
        }
      })]), h("div", {
        "class": classNames.text,
        "attrs": {
          "role": "status"
        }
      }, [h("span", {
        "class": classNames.innerText
      }, [h("span", [this.$slots.default])])]), !actions && truncated && h("div", {
        "class": classNames.expandSingleLine
      }, [h(IconButton, {
        "class": classNames.expand,
        "attrs": {
          "icon-props": {
            iconName: this.state.expandSingleLine ? 'DoubleChevronUp' : 'DoubleChevronDown'
          }
        },
        "nativeOn": {
          "click": this.onClick
        }
      })]), !isMultiline && this.$slots.actions && h("div", {
        "class": classNames.actions
      }, [this.$slots.actions]), this.$listeners.dismiss && isMultiline && h(IconButton, {
        "class": classNames.dismissal,
        "attrs": {
          "icon-props": {
            iconName: 'Clear'
          }
        }
      }), this.$listeners.dismiss && !isMultiline && h("div", {
        "class": classNames.dismissSingleLine
      }, [h(IconButton, {
        "class": classNames.dismissal,
        "attrs": {
          "icon-props": {
            iconName: 'Clear'
          }
        }
      })])]), isMultiline && this.$slots.actions && h("div", {
        "class": classNames.actions
      }, [this.$slots.actions])])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          className = this.className,
          messageBarType = this.messageBarType,
          actions = this.actions,
          truncated = this.truncated,
          isMultiline = this.isMultiline;
      var expandSingleLine = this.state.expandSingleLine;
      return getClassNames(this.styles, {
        theme: theme,
        messageBarType: messageBarType || MessageBarType.info,
        onDismiss: this.$listeners.dismiss !== undefined,
        actions: actions !== undefined,
        truncated: truncated,
        isMultiline: isMultiline,
        expandSingleLine: expandSingleLine,
        className: className
      });
    }
  }]);

  return MessageBarBase;
}(BaseComponent);

__decorate([Prop({
  type: Number,
  default: MessageBarType.info
}), __metadata("design:type", Number)], MessageBarBase.prototype, "messageBarType", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], MessageBarBase.prototype, "isMultiline", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], MessageBarBase.prototype, "actions", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], MessageBarBase.prototype, "truncated", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], MessageBarBase.prototype, "expandSingleLine", void 0);

__decorate([Watch('expandSingleLine'), __metadata("design:type", Function), __metadata("design:paramtypes", [Boolean]), __metadata("design:returntype", void 0)], MessageBarBase.prototype, "onExpandSingleLine", null);

MessageBarBase = __decorate([Component({
  components: {
    Icon: Icon,
    IconButton: IconButton
  }
})], MessageBarBase);

export { MessageBarBase };
